@@ -65,10 +65,11 @@ class Daemon(object):
         return True
 
     def __updateValues(self, dataSources, type, changes, now):
-         for ds in dataSources:
+        for ds in dataSources:
             values = ds.read(type)
             for key, value in ds.decideStoreableValues(values, changes).items():
                 print "%s -> %s" % (key, value)
-                self.dataStorage.addObservation(key, value, now + ds.timestampAdjust(key))
+                self.dataStorage.addObservation(key, value, now + ds.timestampAdjust(key), False)
                 ds.markUpdated(key, value, now)
+        self.dataStorage.con.commit()
        
