@@ -44,11 +44,12 @@ class DataStorage(object):
                 pass
         self.con.commit()
 
-    def addObservation(self, type, value, unixtime):
+    def addObservation(self, type, value, unixtime, commit=True):
         cursor = self.con.cursor()
         cursor.execute('insert into observation (type, value, timestamp) values ((select id from observation_type where name = ?), ?, ?)',
                        (type, value, int(unixtime)))
-        self.con.commit()
+        if commit:
+            self.con.commit()
 
     def __getObservations(self, cursor, type, start, end):
         #t1 = time.time()
@@ -103,6 +104,25 @@ class DataStorage(object):
         except:
             return None
 
+    def getMaxCharge(self):
+        cursor = self.con.cursor()
+        cursor.execute('''select max(cast(value as integer))
+                          from observation
+                          where type = (select id from observation_type where name = ?)''',
+                       ('hal.battery.reporting.design', ))
+        try:
+            return cursor.fetchone()[0]
+        except:
+            return None
+
+    def getOldestObservationTime(self):
+        cursor = self.con.cursor()
+        cursor.execute('''select min(timestamp) from observation''')
+        try:
+            return cursor.fetchone()[0]
+        except:
+            return 0
+
     def countObservations(self):
         cursor = self.con.cursor()
         cursor.execute('select count(id) from observation')
@@ -115,6 +135,21 @@ class DataStorage(object):
         self.con.commit()
         cursor.execute('vacuum')
 
+    def setConfig(self, key, value):
+        cursor = self.con.cursor()
+        cursor.execute('insert or replace into config (name, value) values (?, ?)',
+                       (key, value))
+        self.con.commit()
+        
+    def getConfig(self, key, default = None):
+        cursor = self.con.cursor()
+        cursor.execute('select value from config where name = ?',
+                       (key, ))
+        try:
+            return cursor.fetchone()[0]
+        except:
+            return default
+
     def createTables(self):
         tables = ['''
             config (
@@ -136,9 +171,12 @@ class DataStorage(object):
                 unique (name)
             )''']
         indexes = ['timestamp_index on observation (timestamp)']
+        uniques = ['config_unique_index on config (name)']
         cursor = self.con.cursor()
         for table in tables:
             cursor.execute('create table if not exists %s' % table)
         for index in indexes:
             cursor.execute('create index if not exists %s' % index)
+        for unique in uniques:
+            cursor.execute('create unique index if not exists %s' % unique)
 
