@@ -163,7 +163,7 @@ class MainWindow(hildon.StackableWindow):
                       '28 days': now - 28 * 86400,
                       'Delete all': now + 1}
             self.dataStorage.deleteObservations(values[selector.get_current_text()])
-            self.graph.updateData()
+            self.graph.update()
         note.destroy()
        
     def changeZoom(self, selector, user_data):
